@@ -32,15 +32,14 @@ pub fn home()->Result<String, VarError> {
     env::var("HOME")
 }
 
-/*
-the main 'getter' function
-This basically checks env::var(whatever) and returns the right results
-*/
+/// the main 'getter' function
+/// This basically checks env::var(whatever) and returns the right results
 fn var_getter(env_var:&str, directory:String)->Result<String, VarError> {
     match env::var(env_var) {
         Ok(val)=> return Ok(val),
         Err(_e)=> {
-            if directory.is_empty() {
+            // make sure the direcory exists!
+            if !Path::new(directory.as_str()).is_dir() {
                 return Err(VarError::NotPresent)
             }
             return Ok(String::from(directory))
@@ -129,6 +128,7 @@ pub fn trash()->Result<String, VarError> {
     }
     Ok(String::from(""))
 }
+
 /// loop xdg data dirs
 #[allow(dead_code)]
 pub fn loop_data_dirs(directory:String)->Result<String, VarError> {
@@ -139,9 +139,8 @@ pub fn loop_data_dirs(directory:String)->Result<String, VarError> {
         let res_list = result2.unwrap().to_owned();
         for item in res_list.split(':') {
             let mut tmp_path:String = item.to_owned();
-            //TODO check for directory existence
             tmp_path.push_str(directory.as_str());
-            if Path::new(tmp_path.as_str()).exists() {
+            if Path::new(tmp_path.as_str()).is_dir() {
                 tmp_path.push_str(":");
                 result.push_str(tmp_path.as_str());
             }
@@ -152,20 +151,71 @@ pub fn loop_data_dirs(directory:String)->Result<String, VarError> {
     if home_dir.is_ok() {
         let mut d = home_dir.unwrap().to_owned();
         d.push_str(directory.as_str());
-        if Path::new(d.as_str()).exists() {
+        if Path::new(d.as_str()).is_dir() {
+            d.push_str(":");
             result.push_str(d.as_str());
+            fail = false;
         }
     }
     else {fail = true;}
     if fail {return Err(VarError::NotPresent)}
     Ok(result)
 }
-/// MENU DIRECTORIES
+pub fn data_dirs_vec(directory:String)->Vec<String> {
+    let mut result:Vec<String> = vec![];
+    let result2 = data_dirs();
+    if result2.is_ok() {
+        let res_list = result2.unwrap().to_owned();
+        for item in res_list.split(':') {
+            let mut tmp_path:String = item.to_owned();
+            tmp_path.push_str(directory.as_str());
+            if Path::new(tmp_path.as_str()).exists() {
+                result.push(tmp_path.to_owned());
+            }
+        }
+    }
+    let home_dir = data_home();
+    if home_dir.is_ok() {
+        let mut d = home_dir.unwrap().to_owned();
+        d.push_str(directory.as_str());
+        if Path::new(d.as_str()).exists() {
+            result.push(d);
+        }
+    }
+    result.sort();
+    result.dedup();
+    result
+}
+/// The /menu directory
 #[allow(dead_code)]
 pub fn menu()->Result<String, VarError> {
-    loop_data_dirs("/menu".to_string())
+    let result = config_dirs();
+    let mut retval:String = "".to_string();
+    if result.is_ok() {
+        retval = result.unwrap().to_owned();
+        retval.push_str("/menu");
+    }
+    if Path::new(retval.as_str()).is_dir() {
+        return Ok(retval)
+    }
+    return Err(VarError::NotPresent)
 }
-/// APPLICATIONS DIRECTORIES
+/// the /menu/applications-merged directory
+#[allow(dead_code)]
+pub fn menu_merged()->Result<String, VarError> {
+    let result = config_dirs();
+    let mut retval:String = "".to_string();
+    if result.is_ok() {
+        retval = result.unwrap().to_owned();
+        retval.push_str("/menu/applications-merged");
+    }
+    if Path::new(retval.as_str()).is_dir() {
+        return Ok(retval)
+    }
+    return Err(VarError::NotPresent)
+}
+
+/// the /applications directories
 #[allow(dead_code)]
 pub fn applications()->Result<String, VarError> {
     loop_data_dirs("/applications".to_string())
@@ -176,7 +226,7 @@ pub fn desktop_directories()->Result<String, VarError> {
     loop_data_dirs("/desktop-directories".to_string())
 }
 
-/// AUTOSTART DIRECTORIES
+/// 
 #[allow(dead_code)]
 pub fn autostart()->Result<String, VarError> {
     loop_data_dirs("/autostart".to_string())
@@ -199,3 +249,19 @@ pub fn icon_dirs()->Result<String, VarError> {
     retval.push_str("/usr/share/pixmaps:");
     Ok(retval)
 }
+/// Vector of Icon directories
+pub fn icon_dirs_vector()->Vec<String> {
+    // make our directory of icons
+    let mut directory_vec:Vec<String> = data_dirs_vec("/icons".to_string());
+    let local_icons_dir = home();
+    let mut local_icons:String = "".to_string();
+    if local_icons_dir.is_ok() {
+        local_icons = local_icons_dir.unwrap().to_owned();
+        local_icons.push_str("./icons");
+        directory_vec.push(local_icons.to_owned());
+    }
+    directory_vec.push("/usr/share/pixmaps".to_string());
+    directory_vec.sort();
+    directory_vec.dedup();
+    directory_vec
+}
