@@ -27,6 +27,7 @@ mod icon_theme;
 mod desktop_menu;
 mod utils;
 mod categories;
+mod icon_finder;
 
 extern crate clap;
 use clap::{App, load_yaml};
@@ -44,6 +45,9 @@ fn main() {
         if matches.is_present("Menus") {
             println!("{}",basedir::menu().unwrap_or("".to_string()));
         }
+        if matches.is_present("MenusMerged") {
+            println!("{}",basedir::menu_merged().unwrap_or("".to_string()));
+        }
         if matches.is_present("Applications") {
             println!("{}",basedir::applications().unwrap_or("".to_string()));
         }
@@ -74,8 +78,18 @@ fn main() {
         if matches.is_present("Config") {
             println!("{}",basedir::config_dirs().unwrap_or("".to_string()));
         }
-}
-
+    }
+    //
+    if let Some(matches) = matches.subcommand_matches("findicon") {
+    // Read the desktop file
+        let icon_name = matches.value_of("ICON_NAME").unwrap();
+        // TODO scale/size
+        let icon = match icon_finder::find_icon(icon_name.to_string(),48,1){
+            Some(icon)=>icon,
+            None=>String::from(""),
+        };
+        println!("{:?}",icon);
+    }
 // desktop-entry ARGS
     if let Some(matches) = matches.subcommand_matches("desktop-entry") {
     // Read the desktop file
@@ -109,10 +123,20 @@ fn main() {
             println!("{:?}",desktop_file.hidden.unwrap_or_default());
         }
         if matches.is_present("OnlyShowIn") {
-            println!("{:?}",desktop_file.only_show_in.unwrap_or_default());
+            if desktop_file.only_show_in.is_some() {
+                for item in desktop_file.only_show_in.unwrap_or_default() {
+                    print!("{:?};", item.to_string());
+                }
+            }
+            print!("\n");
         }
         if matches.is_present("NotShowIn") {
-            println!("{:?}",desktop_file.not_show_in.unwrap_or_default());
+            if desktop_file.not_show_in.is_some() {
+                for item in desktop_file.not_show_in.unwrap_or_default() {
+                    print!("{:?};", item.to_string());
+                }
+            }
+            print!("\n");
         }
         if matches.is_present("DBusActivatable") {
             println!("{:?}",desktop_file.dbus_activatable.unwrap_or_default());
